==> MIDITrail-Ver.1.3.5-macOS_src.zip: MIDITrail/Sources/OGLUtility/OGLColorUtil.mm <==
//******************************************************************************
//
// OpenGL Utility / OGLColorUtil
//
// カラーユーティリティクラス
//
// Copyright (C) 2010-2017 WADA Masashi. All Rights Reserved.
//
//******************************************************************************

#import "OGLColorUtil.h"


//******************************************************************************
// コンストラクタ
//******************************************************************************
OGLColorUtil::OGLColorUtil(void)
{
}

//******************************************************************************
// デストラクタ
//******************************************************************************
OGLColorUtil::~OGLColorUtil(void)
{
}

//******************************************************************************
// RGBA（16進数文字列）からの数値変換
//******************************************************************************
OGLCOLOR OGLColorUtil::MakeColorFromHexRGBA(
		const NSString* pHexRGBA
	)
{
	float cr = 0.0f;
	float cg = 0.0f;
	float cb = 0.0f;
	float alpha = 0.0f;
	const char* rgba = NULL;
	char* stopped = NULL;
	char buf[3];
	
	if (pHexRGBA == nil) goto EXIT;
	
	rgba = [pHexRGBA cStringUsingEncoding:NSASCIIStringEncoding];
	if (strlen(rgba) < 4) goto EXIT;
	
	buf[2] = '\0';
	
	buf[0] = rgba[0];
	buf[1] = rgba[1];
	cr     = strtoul(buf, &stopped, 16) / 255.0f;
	
	buf[0] = rgba[2];
	buf[1] = rgba[3];
	cg     = strtoul(buf, &stopped, 16) / 255.0f;
	
	buf[0] = rgba[4];
	buf[1] = rgba[5];
	cb     = strtoul(buf, &stopped, 16) / 255.0f;
	
	buf[0] = rgba[6];
	buf[1] = rgba[7];
	alpha  = strtoul(buf, &stopped, 16) / 255.0f;
	
EXIT:;
	return OGLCOLOR(cr, cg, cb, alpha);
}

==> MIDITrail-Ver.2.0.1-macOS_src.zip: MIDITrail/Sources/OGLUtility/OGLColorUtil.mm <==
//******************************************************************************
//
// OGL Utility / OGLColorUtil
//
// カラーユーティリティクラス
//
// Copyright (C) 2010-2022 WADA Masashi. All Rights Reserved.
//
//******************************************************************************

#import "OGLColorUtil.h"
#import <string.h>  // for strlen
#include <stdlib.h>  // for strtoul


//******************************************************************************
// コンストラクタ
//******************************************************************************
OGLColorUtil::OGLColorUtil(void)
{
}

//******************************************************************************
// デストラクタ
//******************************************************************************
OGLColorUtil::~OGLColorUtil(void)
{
}

//******************************************************************************
// RGBA（16進数文字列）からの数値変換
//******************************************************************************
OGLCOLOR OGLColorUtil::MakeColorFromHexRGBA(
		const NSString* pHexRGBA
	)
{
	float cr = 0.0f;
	float cg = 0.0f;
	float cb = 0.0f;
	float alpha = 0.0f;
	const char* rgba = NULL;
	char* stopped = NULL;
	char buf[3];
	
	if (pHexRGBA == nil) goto EXIT;
	
	rgba = [pHexRGBA cStringUsingEncoding:NSASCIIStringEncoding];
	if (strlen(rgba) < 8) goto EXIT;
	
	buf[2] = '\0';
	
	buf[0] = rgba[0];
	buf[1] = rgba[1];
	cr     = strtoul(buf, &stopped, 16) / 255.0f;
	
	buf[0] = rgba[2];
	buf[1] = rgba[3];
	cg     = strtoul(buf, &stopped, 16) / 255.0f;
	
	buf[0] = rgba[4];
	buf[1] = rgba[5];
	cb     = strtoul(buf, &stopped, 16) / 255.0f;
	
	buf[0] = rgba[6];
	buf[1] = rgba[7];
	alpha  = strtoul(buf, &stopped, 16) / 255.0f;
	
EXIT:;
	return OGLCOLOR(cr, cg, cb, alpha);
}

//******************************************************************************
// 数値からRGBA（16進数文字列）への変換
//******************************************************************************
NSString* OGLColorUtil::MakeHexRGBAFromColor(
		OGLCOLOR color
	)
{
	NSString* pHexRGBA = nil;
	
	pHexRGBA = [NSString stringWithFormat:@"%02X%02X%02X%02X",
					(unsigned int)(color.r * 255.0f),
					(unsigned int)(color.g * 255.0f),
					(unsigned int)(color.b * 255.0f),
					(unsigned int)(color.a * 255.0f)];
	
	return pHexRGBA;
}
